/*
 * Copyright (c) 2019 Jolla Ltd.
 * Copyright (c) 2019 Open Mobile Platform LLC.
 *
 * You may use this file under the terms of BSD license as follows:
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 *   3. Neither the name of Jolla Ltd nor the names of its contributors may
 *      be used to endorse or promote products derived from this software
 *      without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation
 * are those of the authors and should not be interpreted as representing
 * any official policies, either expressed or implied.
 */

#include "qmcenameowner.h"
#include "qmceproxy.h"

// ==========================================================================
// QMceNameOwner::Private
// ==========================================================================

class QMceNameOwner::Private : public QObject
{
    Q_OBJECT
public:
    Private(QMceNameOwner *aParent);
    QMceNameOwner *iParent;
    QSharedPointer<QMceProxy> iProxy;
};

QMceNameOwner::Private::Private(QMceNameOwner *aParent) :
    QObject(aParent),
    iParent(aParent),
    iProxy(QMceProxy::instance())
{
    QObject::connect(iProxy.data(), &QMceProxy::nameOwnerIsKnownChanged,
                     iParent, &QMceNameOwner::validChanged);
    QObject::connect(iProxy.data(), &QMceProxy::nameOwnerChanged,
                     iParent, &QMceNameOwner::nameOwnerChanged);
}

// ==========================================================================
// QMceNameOwner
// ==========================================================================

QMceNameOwner::QMceNameOwner(QObject *aParent)
    : QObject(aParent)
    , iPrivate(new Private(this))
{
}

bool QMceNameOwner::valid() const
{
    return iPrivate->iProxy->nameOwnerIsKnown();
}

QString QMceNameOwner::nameOwner() const
{
    return iPrivate->iProxy->nameOwner();
}

#include "qmcenameowner.moc"
